@@ -648,11 +648,14 @@ class Client(object):
         
         try:
             resp = self.api_request(str(item_list_url), method="DELETE")
+            respd = json.loads(resp)
+            # all good if it says success
+            return 'success' in respd
         except APIError as e:
             if e.http_status_code == 302:
                 return True
             else:
-                raise APIError
+                raise e
 
     
     def sparql_query(self, collection_name, query):
